require "import"
import "android.widget.*"

-- 定义页面布局
local layout = {
    LinearLayout,
    orientation = "vertical",
    layout_height = "fill",
    layout_width = "fill",
    {
        LinearLayout,
        orientation = "vertical",
        -- layout_height = "85%h",
        layout_weight = 9,
        layout_width = "fill",
        id = "listContainer"
    },
    {
        LinearLayout,
        orientation = "horizontal",
        -- layout_height = "10%h",
        layout_weight = 1,
        layout_width = "fill",
        {
            Button,
            id = "selectAllBtn",
            text = "全选"
        },
        {
            Button,
            id = "reverseBtn",
            text = "反选"
        },
        {
            Button,
            id = "cancelBtn",
            text = "取消"
        },
        {
            Button,
            id = "okBtn",
            text = "确定"
        }
    }
}

-- 多选选择器
local function MultiSelector()
    local multiSelector = {} -- 生成的实例
    local views = {}
    local linearLayout = loadlayout(layout, views)
    local dlg = LuaDialog().setView(linearLayout).setCancelable(false)
    local dlg2 = LuaDialog().setMultiChoiceItems({}, {})
    local listView = dlg2.getListView()
    views.listContainer.addView(listView)

    local _items = {} -- 候选项
    local _defaultChecked = {} -- 默认选中项
    local onClickCancel = function()
    end
    local onClickOk = function(selectedIndex)
    end

    multiSelector.setTitle = function(title)
        dlg.setTitle(title)
        return multiSelector
    end

    multiSelector.setItems = function(items, defaultChecked)
        if nil == defaultChecked then
            defaultChecked = {}
        end
        if type(items) ~= "table" or type(defaultChecked) ~= "table" then
            error("类型错误")
        end
        _items = table.clone(items)
        _defaultChecked = table.clone(defaultChecked)
        -- 消除lua与java数组索引的偏差
        for i = 1, #_defaultChecked, 1 do
            _defaultChecked[i] = _defaultChecked[i] - 1
        end
        dlg2.setMultiChoiceItems(_items, _defaultChecked)
        return multiSelector
    end

    multiSelector.show = function()
        dlg.show()
        return multiSelector
    end

    multiSelector.setOnClickCancel = function(fn)
        if type(fn) ~= "function" then
            error("fn 必须是函数类型")
        end
        onClickCancel = fn
        return multiSelector
    end

    multiSelector.setOnClickOk = function(fn)
        if type(fn) ~= "function" then
            error("fn 必须是函数类型")
        end
        onClickOk = fn
        return multiSelector
    end

    -- 注册按钮的点击事件

    -- 全选
    views.selectAllBtn.onClick = function()
        for i = 1, #_items do
            listView.setItemChecked(i - 1, true)
        end
    end

    -- 反选
    views.reverseBtn.onClick = function()
        for i = 1, #_items do
            local checked = true
            if listView.isItemChecked(i - 1) then
                checked = false
            end
            listView.setItemChecked(i - 1, checked)
        end
    end

    -- 取消
    views.cancelBtn.onClick = function()
        dlg.dismiss()
        onClickCancel()
    end

    -- 确定
    views.okBtn.onClick = function()
        local checkedItems = {}
        for i = 1, #_items do
            if listView.isItemChecked(i - 1) then
                table.insert(checkedItems, i)
            end
        end
        dlg.dismiss()
        onClickOk(checkedItems)
    end

    -- 区间选择
    local startPosition = nil -- 区间开始处
    listView.onItemLongClick = function(l, v, p, i)
        -- 第一次长按，记录开始点
        if not startPosition then
            startPosition = p
            return
        end
        -- 第二次长按，选中开始点至长按处的所有项目，并清除开始点
        local step = 1 -- 判断选择方向
        if startPosition > p then
            step = -1
        end
        for i = startPosition, p, step do
            l.setItemChecked(i, true)
        end
        startPosition = nil
    end

    return multiSelector
end

return MultiSelector
