local detectFriends = require "detectFriends"
local friendsManager = require "friendsManager"
local tools = require "tools"
local timer = require "timer"

-- 检测完成后的回调
local function onDetectComplete(detectedNum, resultTables)
    -- 结束计时
    local diffTime = timer.endTiming("detect")
    -- 保存检测结果
    for k, v in pairs(resultTables) do
        friendsManager.set(k, v)
        friendsManager.write(k)
    end

    -- 显示通知
    local messages = {
        string.format("总人数： %d", #friendsManager.get("selectedFriends")),
        string.format("已检测人数： %d", detectedNum),
        string.format("总用时： %d时 %d分 %d秒", tools.splitSeconds(diffTime)),
        string.format("平均用时： %.2f秒", diffTime / detectedNum),
    }
    local dlg = LuaDialog().setTitle("检测结束")
    dlg.setItems(messages)
    dlg.setCancelable(false)
    dlg.setButton("查看检测结果", function()
        local showDetectResult = require "showDetectResult"
        showDetectResult()
    end)
    dlg.show()
    -- 清理全局变量
    detection = nil
end

local function detectFriends_dialog()
    -- 初始化
    local selectedFriends = friendsManager.read("selectedFriends")

    -- 未选择好友
    if #selectedFriends == 0 then
        LuaDialog().setMessage("您还没有选择好友，无法开始检测").setButton("确定", mainMenu).show()
        return false
    end

    -- 弹窗确认
    local messages = { "您选择了" .. #selectedFriends .. "位好友",
        "检测时间可能较长，请勿退出微信或关闭屏幕，若想中途停止，可长按音量减小建启动语音助手，说：微信好友检测，即可停止" }
    local dlg = LuaDialog()
    dlg.setTitle("开始检测")
    dlg.setItems(messages)
    dlg.setCancelable(false)
    dlg.setNegativeButton("取消", mainMenu)
    dlg.setPositiveButton("开始", function()
        timer.startTiming("detect") -- 开始计时
        detection = detectFriends(selectedFriends, onDetectComplete)
    end)
    dlg.show()
    return true
end

return detectFriends_dialog
