local tools = require "tools"
local friendsManager = {}
local tables = {
    allFriends = {}, -- 全部的好友
    selectedFriends = {}, -- 已选中的好友
    deletedFriends = {}, -- 将你删除的好友
    badFriends = {}, -- 账号存在问题的好友
    blacklistFriends = {}, -- 将你拉入黑名单的好友
    failedFriends = {} -- 检测失败的好友
}

local _storagePath = {
    allFriends = PATH.ALL_FRIENDS,
    selectedFriends = PATH.SELECTED_FRIENDS,
    deletedFriends = PATH.DELETED_FRIENDS,
    badFriends = PATH.BAD_FRIENDS,
    blacklistFriends = PATH.BLACKLIST_FRIENDS,
    failedFriends = PATH.FAILED_FRIENDS
}

-- 获取对应的数据表
-- 失败抛出异常，成功返回表的引用
friendsManager.get = function(tableName)
    return tables[tableName]
end

-- 设置指定数据表的内容，不改变表的引用
-- 失败抛出异常，成功返回true
friendsManager.set = function(tableName, data)
    local tab = tables[tableName]
    if nil == tab then
        error('"' .. tableName .. '"不存在')
    end
    if type(data) ~= "table" then
        error("数据格式有误")
    end
    table.clear(tab)
    for i, v in ipairs(data) do
        tab[i] = v
    end
    return true
end

-- 从文件读取指定数据表的内容
-- 失败抛出异常，成功返回数据表的引用
friendsManager.read = function(tableName)
    local tab = tables[tableName]
    if nil == tab then
        error('"' .. tableName .. '"不存在')
    end
    local res = tools.readJsonFile(_storagePath[tableName])
    friendsManager.set(tableName, res)
    return tab
end

-- 将friends[key]的数据写入文件
-- 失败抛出异常，成功返回true
friendsManager.write = function(tableName)
    local tab = tables[tableName]
    if nil == tab then
        error('"' .. tableName .. '"不存在')
    end
    return tools.writeJsonFile(_storagePath[tableName], tab)
end

-- 清空所有数据表
friendsManager.clear = function()
    for k, v in pairs(tables) do
        table.clear(tables[k])
    end
end

return friendsManager
