require "import"
local cjson = import "cjson"
local Toast = import "android.widget.Toast"

local tools = {}

-- 数组去重
-- 不改变元素的顺序
tools.arrayToSet = function(oldArr)
    local newArr = {}
    for index, value in ipairs(oldArr) do
        if not tools.includes(newArr, value) then
            table.insert(newArr, value)
        end
    end
    return newArr
end

-- 判断数组中是否包含指定元素
tools.includes = function(array, item)
    for index, value in ipairs(array) do
        if value == item then
            return true
        end
    end
    return false
end

-- 在数组中查找元素的索引
tools.indexOf = function(arr, value)
    for i = 1, #arr do
        if value == arr[i] then
            return i
        end
    end
    return -1
end

-- 将t2的元素追加到t1
tools.append = function(t1, t2)
    for i, v in ipairs(t2) do
        table.insert(t1, v)
    end
end

-- 读取json文件
-- path	json文件的路径
-- 返回解析后的json
tools.readJsonFile = function(path)
    local file = io.open(path, "r")
    if nil == file then
        error("打开文件失败")
    end
    local json = file:read("*a")
    file:close()
    return cjson.decode(json)
end

-- 写入json文件
-- path	json文件的路径
-- data	需写入的数据
tools.writeJsonFile = function(path, data)
    local file = io.open(path, "w")
    if nil == file then
        error("打开文件失败")
    end
    local text = cjson.encode(data)
    file:write(text)
    file:close()
    return true
end

-- 显示Toast
tools.showToast = function(text, showTime)
    if nil == showTime then
        showTime = Toast.LENGTH_SHORT
    end
    return Toast.makeText(this, text, showTime).show()
end

-- 将秒数分割为时分秒
tools.splitSeconds = function(n)
    local hour, minute, second
    second = n % 60
    n = (n - second) / 60
    minute = n % 60
    hour = (n - minute) / 60
    return hour, minute, second
end

return tools
